#
# spec file for package ginac
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define library_version 6
Name:           ginac
Version:        1.7.4
Release:        lp151.2.4
Summary:        C++ library for symbolic calculations
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://www.ginac.de/
Source0:        https://www.ginac.de/%{name}-%{version}.tar.bz2
BuildRequires:  cln-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  readline-devel

%description
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

%package -n libginac%{library_version}
Summary:        C++ library for symbolic calculations
Group:          System/Libraries

%description -n libginac%{library_version}
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

%package -n libginac-devel
Summary:        GiNaC development libraries and header files
Group:          Development/Libraries/C and C++
Requires:       cln-devel
Requires:       libginac%{library_version} = %{version}
PreReq:         %{install_info_prereq}

%description -n libginac-devel
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

This package contains the libraries, include files and other resources you
use to develop GiNaC applications.

%prep
%setup -q

%build
%configure --disable-static --disable-rpath
make %{?_smp_mflags}

%check
export MALLOC_CHECK_=2
make %{?_smp_mflags} check
unset MALLOC_CHECK_

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libginac%{library_version} -p /sbin/ldconfig
%postun -n libginac%{library_version} -p /sbin/ldconfig
%post -n libginac-devel
%install_info --info-dir=%{_infodir} %{_infodir}/ginac.info.gz

%preun -n libginac-devel
%install_info_delete  --info-dir=%{_infodir} %{_infodir}/ginac.info.gz

%files -n libginac%{library_version}
%{_libdir}/libginac.so.%{library_version}*

%files -n libginac-devel
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so
%{_libdir}/pkgconfig/ginac.pc
%dir %{_includedir}/ginac
%{_includedir}/ginac/*.h
%{_infodir}/*.info*

%files
%{_bindir}/ginsh
%{_bindir}/viewgar
%{_libexecdir}/ginac-excompiler
%{_mandir}/man1/ginsh.1%{ext_man}
%{_mandir}/man1/viewgar.1%{ext_man}

%changelog
* Fri Apr  6 2018 dimstar@opensuse.org
- Drop baselibs.conf completely: This was introdcued two years ago
  but in this entire time, nobody cared that the resulting -32bit
  library was not installable due to missing dependencies. So it
  is obvioulsy not used.
* Wed Apr  4 2018 dimstar@opensuse.org
- Drop ginac-devel from baselibs: baselibs was produced in 2016,
  but the deps for it where never in place, which means
  ginac-devel-32bit was never installable, and nobody cared.
  Clearly this -32bit package is not used (for -devel there is
  rarely a need for a -32bit package).
* Sun Mar 11 2018 badshah400@gmail.com
- Update to version 1.7.4:
  * Fix ABI compatibility with 1.7.[0-2] (broken unintentionally
    in 1.7.3).
* Sun Feb  4 2018 jengelh@inai.de
- Remove --with-pic which has no effect with --disable-static.
- Fix the shlib package's RPM groups.
* Sat Feb  3 2018 avindra@opensuse.org
- Update to 1.7.3:
  * Speed up some corner cases of polynomial factorization.
  * Speed up some corner cases of gcd computation.
  * Speed up factorization of pre-factored polynomials.
  * Make matrix::solve() work with hidden (non-normal) zeros.
  * Fix bug in evaluation of real and imaginary parts of powers.
  * Fix some LaTeX output, add new function symbol::get_TeX_name().
- cleanup with spec-cleaner
* Mon Jan 30 2017 badshah400@gmail.com
- Update to version 1.7.2:
  * Fix memory leak in operators returning relationals, introduced
    in 1.7.0.
  * Make macro GINAC_DECLARE_REGISTERED_CLASS() work outside
    namespace GiNaC.
  * Fix some build issues.
- Drop ginac-replace-mktemp-with-mkstemp.patch: incorporated
  upstream.
* Fri Nov 25 2016 badshah400@gmail.com
- Fix baselibs.conf file.
* Mon Nov 21 2016 badshah400@gmail.com
- Add ginac-replace-mktemp-with-mkstemp.patch: Replace unsafe and
  deprecated mktemp by its safe variant mkstemp; patch taken from
  upstream git and fixes an rpmlint warning.
* Mon Nov 21 2016 badshah400@gmail.com
- Update to version 1.7.1:
  * Fix crash in basic::subs(), visible in classes which don't
    override it.
  * Fix convergence failure in Li_projection.
  * Fix cliffor_bar() and clifford_star().
  * Improve performance of clifford_to_lst().
  * Fix compilation issues, reduce compiler warnings.
- Changes from version 1.7.0:
  * Make use of C++11 features:
  - Use new language features 'auto', 'nullptr', 'constexpr',
    range-based for loops, the contextual keyword 'override',
    static 'noexcept' operator, etc.
  - Add initializer list ctors for container<>, lst and nested
    initializer lists ctor for class matrix.
  - Add many rvalue reference overloads for ctors from std
    containers. (Note that whether they really speed up things
    depends on whether evaluation leaves the container unchanged
    or not.)
  - Rvalue reference overloads for ctors from std containers
    made it possible to remove the manual 'discardable' hack and
    std::auto_ptr<T> for good.
  - New dynallocate<T>(args...) helper functions obsolete manual
    allocation on the heap and setting the dynallocated status
    flag.
  - Got rid of C++98ish algorithm features (bind2nd, etc.) and
    replaced them with lambdas.
  * Make add::eval(), mul::eval() more careful so they return an
    evaluated, canonical expression without compromise.
  * Remove 'level' argument of all .eval() methods.
  * Remove 'level' arguments of all .evalf() and .normal()
    methods. They were modeled after the .eval() methods.
  * Make relational::rhs() and lhs() nonvirtual.
  * Add support for power::info(info_flags::real).
  * Add fderivative::derivatives() method.
  * Remove broken info_flags::algebraic.
  * Remove unmaintained support for Cint.
  * Remove unfinished code for hash table-based expairseq.
  * Remove deprecated ex::to_rational(lst) and
    ex::to_polynomial(lst).
  * ginac-excompiler installs in $LIBEXECDIR now, not in $BINDIR.
  * Many minor performance enhancements.
- Changes from previous versions 1.6.3 through 1.6.7: See
  http://www.ginac.de/News.html.
- Add a baselibs.conf file.
- Drop ginac-return-in-nonvoid.patch, no longer required.
* Mon Dec 12 2011 pgajdos@suse.com
- added libtool into explicit build requires
* Sat Nov 19 2011 werner.ho@gmx.de
- new version 1.6.2
* Sun Oct 23 2011 arun@gmx.de
- added patch (git commit 265e5f9537)
* Tue May 24 2011 pgajdos@novell.com
- updated to 1.6.0
* Thu Aug 19 2010 pgajdos@suse.cz
- updated to 1.5.7
  * upstreamed gcc45.patch
* Tue Feb 23 2010 pgajdos@suse.cz
- fixed build with gcc 4.5
  * gcc45.patch
* Mon Feb  1 2010 pgajdos@suse.cz
- updated to 1.5.6
- disable rpath
- library_version variable in spec file
* Thu Jun 26 2008 crrodriguez@suse.de
- run make check
* Tue Oct 30 2007 crrodriguez@suse.de
- first version for the OBS
